@@ -70,16 +70,20 @@ def metrics_date(table_name: str, col_name: str, dtype: str):
         return {"dtype": dtype, "unique:": row[0], "min": row[1], "max": row[2], "num_null": row[3]}
 
 
-def column_metrics(table_name: str):
+def column_metrics(table_name: str, column_name: str, dtype: str):
+    if dtype == "STRING":
+        return metrics_string(table_name, column_name, dtype)
+    elif dtype == "DATE":
+        return metrics_date(table_name, column_name, dtype)
+    elif dtype == "FLOAT64" or dtype == "INT64":
+        return metrics_numeric(table_name, column_name, dtype)
+    else:
+        return {"dtype": dtype}
+
+
+def table_metrics(table_name: str):
     out = {}
     dtypes = get_table_dtypes(schema_name, table_name)
     for col, dtype in dtypes.items():
-        if dtype == "STRING":
-            out[col] = metrics_string(table_name, col, dtype)
-        elif dtype == "DATE":
-            out[col] = metrics_date(table_name, col, dtype)
-        elif dtype == "FLOAT64" or dtype == "INT64":
-            out[col] = metrics_numeric(table_name, col, dtype)
-        else:
-            out[col] = {"dtype": dtype}
+        out[col] = column_metrics(table_name, col, dtype)
     return out
\ No newline at end of file
